import { createWebHistory, createRouter } from "vue-router";
/* Layout */
import Layout from "/src/layout";

/**
 * Note: 路由配置项
 *
 * hidden: true                     // 当设置 true 的时候该路由不会再侧边栏出现 如401，login等页面，或者如一些编辑页面/edit/1
 * alwaysShow: true                 // 当你一个路由下面的 children 声明的路由大于1个时，自动会变成嵌套的模式--如组件页面
 *                                  // 只有一个时，会将那个子路由当做根路由显示在侧边栏--如引导页面
 *                                  // 若你想不管路由下面的 children 声明的个数都显示你的根路由
 *                                  // 你可以设置 alwaysShow: true，这样它就会忽略之前定义的规则，一直显示根路由
 * redirect: noRedirect             // 当设置 noRedirect 的时候该路由在面包屑导航中不可被点击
 * name:'router-name'               // 设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
 * query: '{"id": 1, "name": "ry"}' // 访问路由的默认传递参数
 * roles: ['admin', 'common']       // 访问路由的角色权限
 * permissions: ['a:a:a', 'b:b:b']  // 访问路由的菜单权限
 * meta : {
    noCache: true                   // 如果设置为true，则不会被 <keep-alive> 缓存(默认 false)
    title: 'title'                  // 设置该路由在侧边栏和面包屑中展示的名字
    icon: 'svg-name'                // 设置该路由的图标，对应路径src/assets/icons/svg
    breadcrumb: false               // 如果设置为false，则不会在breadcrumb面包屑中显示
    activeMenu: '/system/user'      // 当路由设置了该属性，则会高亮相对应的侧边栏。
  }
 */

// 公共路由
export const constantRoutes = [
  {
    path: "/redirect",
    component: Layout,
    hidden: true,
    children: [
      {
        path: "/redirect/:path(.*)",
        component: () => import("/src/views/redirect/index.vue"),
      },
    ],
  },
  {
    path: "/login",
    component: () => import("/src/views/login.vue"),
    hidden: true,
  },
  {
    path: "/register",
    component: () => import("/src/views/register.vue"),
    hidden: true,
  },
  {
    path: "/:pathMatch(.*)*",
    component: () => import("/src/views/error/404.vue"),
    hidden: true,
  },
  {
    path: "/401",
    component: () => import("/src/views/error/401.vue"),
    hidden: true,
  },
  {
    path: "",
    component: Layout,
    redirect: "/index",
    children: [
      {
        path: "/index",
        component: () => import("/src/views/index.vue"),
        name: "Index",
        meta: { title: "首页", icon: "dashboard", affix: true },
      },
      {
        path: "/platform_manage/process/processApproval",
        component: () => import("/src/views/process/processApproval/index.vue"),
        name: "ProcessApproval",
        meta: { title: "流程审批", icon: "dashboard", affix: false },
      },
    ],
  },
  {
    path: "/user",
    component: Layout,
    hidden: true,
    redirect: "noredirect",
    children: [
      {
        path: "profile",
        component: () => import("/src/views/system/user/profile/index.vue"),
        name: "Profile",
        meta: { title: "个人中心", icon: "user" },
      },
    ],
  },
  {
    path: "/hisMsg",
    component: Layout,
    redirect: "/hisMsg",
    children: [
      {
        path: "/hisMsg",
        name: "hisMsg",
        component: () => import(/* webpackChunkName: "page" */ "@/views/system/msg/hisMsg.vue"),
        props: true,
        meta: { title: "历史消息" },
      },
    ],
  },
  {
    path: "/addOrder",
    component: Layout,
    redirect: "/addOrder",
    children: [
      {
        path: "/addOrder",
        name: "add-order",
        component: () => import(/* webpackChunkName: "page" */ "@/views/subsidiary/order/management/add.vue"),
        props: true,
        meta: { title: "新建订单" },
      },
    ],
  },
  {
    path: "/design-draft",
    component: Layout,
    redirect: "/design-draft",
    children: [
      {
        path: "/design-draft",
        name: "design-draft",
        component: () => import(/* webpackChunkName: "page" */ "@/views/subsidiary/order/management/design.vue"),
        props: true,
        meta: { title: "上传设计稿" },
      },
    ],
  },
  {
    path: "/order-detail",
    component: Layout,
    redirect: "/order-detail",
    children: [
      {
        path: "/order-detail",
        name: "order-detail",
        component: () => import(/* webpackChunkName: "page" */ "@/views/group/order/management/detail.vue"),
        props: true,
        meta: { title: "订单详情" },
      },
    ],
  },
  {
    path: "/already-removed-order-detail",
    component: Layout,
    redirect: "/already-removed-order-detail",
    children: [
      {
        path: "/already-removed-order-detail",
        name: "already-removed-order-detail",
        component: () => import(/* webpackChunkName: "page" */ "@/views/group/order/already-removed/detail.vue"),
        props: true,
        meta: { title: "订单详情" },
      },
    ],
  },
  {
    path: "/charging-standard/addOrModify",
    component: Layout,
    redirect: "/charging-standard/addOrModify",
    children: [
      {
        path: "/charging-standard/addOrModify",
        name: "add-or-modify-charging-standard",
        component: () => import(/* webpackChunkName: "page" */ "@/views/group/selling-price/charging-standard/addOrModify.vue"),
        props: true,
        meta: { title: "计费标准新增/修改" },
      },
    ],
  },
  {
    path: "/putInStorage/add",
    component: Layout,
    redirect: "/putInStorage/add",
    children: [
      {
        path: "/putInStorage/add",
        name: "add-putInStorage",
        component: () => import(/* webpackChunkName: "page" */ "@/views/production/warehouse/putInStorage/add.vue"),
        props: true,
        meta: { title: "入库登记" },
      },
    ],
  },
  {
    path: "/outbound/add",
    component: Layout,
    redirect: "/outbound/add",
    children: [
      {
        path: "/outbound/add",
        name: "add-outbound",
        component: () => import(/* webpackChunkName: "page" */ "@/views/production/warehouse/outbound/add.vue"),
        props: true,
        meta: { title: "出库登记" },
      },
    ],
  },
  {
    path: "/check/add",
    component: Layout,
    redirect: "/check/add",
    children: [
      {
        path: "/check/add",
        name: "add-check",
        component: () => import(/* webpackChunkName: "page" */ "@/views/production/warehouse/check/add.vue"),
        props: true,
        meta: { title: "盘点登记" },
      },
    ],
  },
];
// 动态路由，基于用户权限动态去加载
export const dynamicRoutes = [
  {
    path: "/system/user-auth",
    component: Layout,
    hidden: true,
    permissions: ["system:user:edit"],
    children: [
      {
        path: "role/:userId(\\d+)",
        component: () => import("/src/views/system/user/authRole.vue"),
        name: "AuthRole",
        meta: { title: "分配角色", activeMenu: "/system/user" },
      },
    ],
  },
  {
    path: "/system/role-auth",
    component: Layout,
    hidden: true,
    permissions: ["system:role:edit"],
    children: [
      {
        path: "user/:roleId(\\d+)",
        component: () => import("/src/views/system/role/authUser.vue"),
        name: "AuthUser",
        meta: { title: "分配用户", activeMenu: "/system/role" },
      },
    ],
  },
  {
    path: "/system/dict-data",
    component: Layout,
    hidden: true,
    permissions: ["system:dict:list"],
    children: [
      {
        path: "index/:dictId(\\d+)",
        component: () => import("/src/views/system/dict/data.vue"),
        name: "Data",
        meta: { title: "字典数据", activeMenu: "/system/dict" },
      },
    ],
  },
  {
    path: "/monitor/job-log",
    component: Layout,
    hidden: true,
    permissions: ["monitor:job:list"],
    children: [
      {
        path: "index/:jobId(\\d+)",
        component: () => import("/src/views/monitor/job/log.vue"),
        name: "JobLog",
        meta: { title: "调度日志", activeMenu: "/monitor/job" },
      },
    ],
  },
  {
    path: "/tool/gen-edit",
    component: Layout,
    hidden: true,
    permissions: ["tool:gen:edit"],
    children: [
      {
        path: "index/:tableId(\\d+)",
        component: () => import("/src/views/tool/gen/editTable.vue"),
        name: "GenEdit",
        meta: { title: "修改生成配置", activeMenu: "/tool/gen" },
      },
    ],
  },
];

const router = createRouter({
  history: createWebHistory(),
  routes: constantRoutes,
  scrollBehavior(to, from, savedPosition) {
    if (savedPosition) {
      return savedPosition;
    } else {
      return { top: 0 };
    }
  },
});

export default router;
